@@ -1,6 +1,7 @@
 use std::collections::hash_map::DefaultHasher;
 use std::fs;
 use std::hash::{Hash, Hasher};
+use std::io::{stdin, stdout, Write};
 use std::path::Path;
 
 pub const DEFAULT_FLATPAK_BUILDER_CACHE_DIR: &str = ".flatpak-builder/";
@@ -121,3 +122,22 @@ pub fn format_bytes(bytes: usize) -> String {
     }
     return format!("{:.2} {}", approximated_bytes, sizes[i]);
 }
+
+pub fn ask_yes_no_question(question: String) -> bool {
+    let mut answer = String::new();
+    print!("{}? [Y/n]: ", question);
+    let _ = stdout().flush();
+    stdin()
+        .read_line(&mut answer)
+        .expect("Error while reading answer for question.");
+    if let Some('\n') = answer.chars().next_back() {
+        answer.pop();
+    }
+    if let Some('\r') = answer.chars().next_back() {
+        answer.pop();
+    }
+    if answer == "Y" || answer == "y" {
+        return true;
+    }
+    return false;
+}
